OiRA

Help

1. Preparación
2. Implicación
3. Identificación + Evaluación
4. Plan de acción
5. Informe
6. Grado de cumplimentación 37%

# Estado de Commercial guarding, Leicester

## Información general

Herramienta utilizada

  Commercial guarding, Leicester

iniciada

  5 August 2017 by angela.baumeister@company.com

Guardado

  7 June 2018 by hans.mittelmaier@company.com

## Preguntas respondidas por módulo

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 OK
  - 3
  - 2 Atención
  - 2 Pospuesto
  - 2 Sin respuesta

  #### Riesgos de prioridad alta

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Sin respuesta

  1

  1 Atención

  1 Pospuesto

  - 7 Sin respuesta
  - 1
  - 1 Atención
  - 1 Pospuesto

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More